

clear


version 13


use "C:\Users\rabuza\Documents\Promotion\Text\Kapitel  5 Institutionelle Effekte\Analyse\Data\Aktuellster Datensatz\merge_20150608.dta"


set more off

gen cogcomp_diff = cogcomp_hi - cogcomp_lo


* Generate missing value on explanatory variable *

misschk vote10 ager sex edulvla open dis_gall comp ind_tra ///
fed coord emprot_temp lo_sec cogcomp_diff edusd , gen(miss)

* Centering of continuous predictors at the macro-level


sum ager if missnumber == 0
gen age_z = ager - r(mean)

sum age2 if missnumber == 0
gen age2_z = age2 - r(mean) 

sum edulvla if missnumber == 0
gen edulvla_z = edulvla - r(mean)

egen pickone = tag(cyear) if missnum == 0

sum dis_gall if missnumber == 0  & pickone == 1
gen dis_gall_z = dis_gall - r(mean) if missnumber == 0

sum coord if missnumber == 0 & pickone == 1
gen coord_z = coord - r(mean) if missnumber == 0

sum ind_tra if  missnumber == 0 & pickone == 1
gen ind_tra_z = ind_tra - r(mean) if missnumber == 0

sum voc_spec if missnumber == 0 & pickone == 1
gen voc_spec_z = voc_spec - r(mean) if missnumber == 0

sum emprot_temp if missnumber == 0  & pickone == 1
gen emprot_temp_z = emprot_temp - r(mean) if missnumber == 0


sum emprot_reg if missnumber == 0  & pickone == 1
gen  emprot_reg_z = emprot_reg - r(mean) if missnumber == 0



sum cogcomp_diff if missnumber == 0 & pickone == 1
gen cogcomp_diff_z = cogcomp_diff - r(mean) if missnumber == 0


sum lo_sec_25_64 if missnumber == 0  & pickone == 1
gen lo_sec_25_64_z = lo_sec_25_64 - r(mean) if missnumber == 0


sum edusd if missnum == 0 & pickone == 1
gen edusd_z = edusd - r(mean) if missnumber == 0


sum vote10 age_z sex edulvla if missnumber == 0

pwcorr edusd lo_sec_25_64 cogcomp_diff if missnum ==0 & pickone == 1, sig obs







* Null model


xtmelogit vote10 || cyear: if missnumber == 0, variance 

est store m0

estat icc




**********************
*                    *
* Random Intercept   *
*                    *
**********************

set more off
xtmelogit vote10 edulvla age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
|| cyear: , var mle

est store m1 

lrtest m1 m0 , force

estat icc

set more off
xtmelogit vote10 edulvla age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
lo_sec_25_64_z cogcomp_diff_z  ///
|| cyear: , var mle


*****************
*               *
* Random Slope  *
*               *
*****************

set more off
xtmelogit vote10 edulvla age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z  ///
|| cyear: edulvla, var mle cov(unstructured)

est store m2
estat icc

lrtest m1 m2, force



****************************
*						   *
* Cross-level Interactions *
*                          *
****************************

* 1. Cognitive Competence Difference

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z /// 
edulvla cogcomp_diff_z|| cyear: edulvla, var mle cov(unstructured)

est store m3
estat icc

* model with interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z /// 
c.edulvla##c.cogcomp_diff_z|| cyear: edulvla, var mle cov(unstructured)

est store m4

estat icc
lrtest  m3 m4, force


margins , at(cogcomp_diff_z=(-1(1)2) edulvl=(1(1)5)) predict(fixed)

marginsplot ,recast(line) recastci(rarea)
graph save cogcomp_edu_c2.gph, replace


* 2. Share Low Educated (ISCED 1 and 2)

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla lo_sec_25_64_z|| cyear: edulvla, var mle cov(unstructured)

est store m5
estat icc


* model with interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
c.edulvla##c.lo_sec_25_64_z|| cyear: edulvla, var mle cov(unstructured)

est store m6

estat icc
lrtest  m5 m6, force // test for signficant interaction term

margins , at(lo_sec_25_64_z=(-20(10)60) edulvl=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)


graph save shareloed_edu_c2.gph, replace


* 3. Dispersion of Ecducational Attainment

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla edusd_z|| cyear: edulvla, var mle cov(unstructured)  ///


est store m7
estat icc


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
c.edulvla##c.edusd_z|| cyear: edulvla, ///
var mle cov(unstructured) refineopts(difficult)

est store m8
estat icc
lrtest  m7 m8, force

margins , at(edusd_z=(-2(1)3) edulvla=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save dispersion_edu_c2.gph, replace



* 4. Stratification of Educational System

set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z coord_z ///
edulvla ind_tra_z|| cyear: edulvla, var mle cov(unstructured)

est store m9
estat icc


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z|| cyear: edulvla, var mle cov(unstructured)

est store m10
estat icc

lrtest m9 m10, force

margins , at(ind_tra_z=(-2(1)2) edulvla=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save track_edu_c2.gph, replace




* 5. Employment Protection (Temporarily Employed)

set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z ///
edulvla emprot_temp_z|| cyear: edulvla, var mle cov(unstructured)

est store m11
estat icc

set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z ///
c.edulvla##c.emprot_temp_z|| cyear: edulvla, var mle cov(unstructured)

est store m12
estat icc
lrtest m11 m12, force

margins , at(emprot_temp_z=(-2(1)3) edulvla=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save epl_temp_edu_c2.gph, replace


* 6. Coordination of Economy

set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z ///
edulvla coord_z|| cyear: edulvla, var mle cov(unstructured)

est store m13
estat icc


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z ///
c.edulvla##c.coord_z|| cyear: edulvla, var mle cov(unstructured)

est store m14
estat icc
lrtest m13 m14, force

margins , at(coord_z=(-3(1)2) edulvla=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save coord_edu_c.gph2, replace


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z coord_z ///
edulvla ind_tra_z cogcomp_diff_z|| cyear: edulvla, var mle cov(unstructured)



set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z|| cyear: edulvla, var mle cov(unstructured)

est store m15
lrtest m8 m15

estat icc

margins , at(ind_tra_z=(-2(1)2)  edulvla=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save indtra_edu_c3.gph2, replace


margins , at(cogcomp_diff_z=(-1(1)2)  edulvla=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save cogcomp_edu_c3.gph



set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
|| cyear: edulvla, var mle cov(unstructured)

est store m16

lrtest m15 m16

estat icc

set more off
margins , at(ind_tra_z=(-2(1)2)  edulvla=(1, 5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save indtra_edu_c6.gph, replace

set more off
margins , at(cogcomp_diff_z=(-1(1)2)  edulvla=(1,5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save cogcomp_edu_c6.gph, replace

margins , at(lo_sec_25_64_z=(-20(10)60) edulvla=(1,5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save shareloed_edu_c6.gph, replace

graph combine cogcomp_edu_c6.gph shareloed_edu_c6.gph ///
indtra_edu_c6.gph

graph save comb_edu20150621.gph, replace

set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.emprot_temp ///
|| cyear: edulvla, var mle cov(unstructured)

est store m17

estat icc

lrtest m16 m17




set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
|| cyear: edulvla, var mle cov(unstructured)

est store m18

estat icc

*lrtest m16 m18

set more off
margins , at(ind_tra_z=(-2(1)2)  edulvla=(1, 5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save indtra_edu_c7.gph, replace

margins , at(cogcomp_diff_z=(-1(1)2)  edulvla=(1,5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save cogcomp_edu_c7.gph, replace

margins , at(lo_sec_25_64_z=(-20(10)60) edulvla=(1,5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save shareloed_edu_c7.gph, replace

margins , at(dis_gall_z=(-6(1)18) edulvla=(1,5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save disgall_edu_c7.gph, replace

graph combine indtra_edu_c7.gph cogcomp_edu_c7.gph ///
shareloed_edu_c7.gph disgall_edu_c7.gph ///

graph save comb_disprop20150621.gph, replace



* Stratification, Competence, Share, Disproportionality, open ballot

set more off
xtmelogit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##i.open ///
|| cyear: edulvla, var mle cov(unstructured)

estat icc

est store m19 
lrtest m18 m19


set more off
margins , at(ind_tra_z=(-2(1)2)  edulvla=(1, 5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save indtra_edu.gph, replace

set more off
margins , at(cogcomp_diff_z=(-1(1)2)  edulvla=(1,5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save cogcomp_edu.gph, replace

set more off
margins , at(lo_sec_25_64_z=(-20(10)60) edulvla=(1,5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save shareloed_edu.gph, replace

set more off
margins , at(dis_gall_z=(-6(1)18) edulvla=(1,5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save disgall_edu.gph, replace

set more off
margins , at(open = (0,1) edulvla = (1,5)) predict(fixed)
marginsplot , recast(line) recastci(rarea)

graph save open_edu.gph, replace


graph combine indtra_edu.gph cogcomp_edu.gph ///
shareloed_edu.gph disgall_edu.gph open_edu.gph 

graph save comb_full.gph, replace





* Voc Specificity + Stratification + Disproprotionality + Coordination 
* + Cognitive Compectence Gap

set more off
xtmelogit vote10 age_z age2_z sex ///
dis_gall_z comp  fed open ///
voc_spec_z ind_tra_z  ///
coord_z emprot_temp_z /// /// 
c.edulvla##c.ind_tra_z ///
c.edulvla##c.voc_spec_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.coord_z ///
c.edulvla##c.cogcomp_diff_z ///
|| cyear: edulvla, var mle cov(unstructured)

est store m20
estat icc



set more off
xtmelogit vote10 age_z age2_z sex ///
dis_gall_z comp  fed open ///
voc_spec_z ind_tra_z  ///
coord_z emprot_temp_z /// 
c.edulvla##c.ind_tra_z ///
c.edulvla##c.voc_spec_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.coord_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
|| cyear: edulvla, var mle cov(unstructured) 

est store m21
estat icc 

lrtest  m20 m21 // p = .000 -> relatively best model



estout  m* ///
 using results20160214_socm.csv , noomitted ///
cells("b(star fmt(3)) se[par]") ///
stats(N_g N ll aic bic, labels("N groups" "N individuals" Log-Likelihood ///
AIC BIC)) nolz replace

* Graphs of predicted probabilities

set more off
sum  ind_tra_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(ind_tra_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)


set more off
margins , at(ind_tra_z = (-2(1)2)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Stratifizierung des Bildungssystems", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save ind_tra_wcontrol20151207.gph, replace



set more off
sum  cogcomp_diff_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(cogcomp_diff_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)

set more off
margins , at(cogcomp_diff_z = (-1(1)2)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Differenz kognitive Kompetenz", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save cogcompdiff_wcontrol20151207.gph, replace


set more off
sum  lo_sec_25_64_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(lo_sec_25_64_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)

set more off
margins , at(lo_sec_25_64_z = (-20(10)60)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Anteil gering Gebildeter", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save loedu_wcontrol20151207.gph, replace


* Disporportionality
set more off
sum  dis_gall_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(dis_gall_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)

set more off
margins , at(dis_gall_z = (-6(5)21)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Elektorale Disproportionalitt", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save dis_gall_wcontrol20151207.gph , replace

graph combine dis_gall_wcontrol20151207.gph ///
ind_tra_wcontrol20151207.gph ///
loedu_wcontrol20151207.gph ///
cogcompdiff_wcontrol20151207.gph


graph save comb_full20151207.gph, replace


* 

set more off
xtmelogit vote10 age_z age2_z sex ///
dis_gall_z comp  fed open ///
voc_spec_z ind_tra_z  ///
coord_z emprot_temp_z /// 
c.edulvla##c.ind_tra_z ///
c.edulvla##c.voc_spec_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.coord_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.edusd_z ///
|| cyear: edulvla, var mle cov(unstructured)

est store pm22


lrtest  pm21 pm22  // p = .39





**************************************
*
*  Robustness Checks                 *
*
**************************************


* With Population weight

xtset cyear_n

xtlogit  vote10 age_z age2_z sex ///
dis_gall_z comp  fed open ///
voc_spec_z ind_tra_z  ///
coord_z emprot_temp_z /// 
c.edulvla##c.ind_tra_z ///
c.edulvla##c.voc_spec_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.coord_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z [iweight = pweight] 

est store socrob1

* With Design Weight

logit  vote10 age_z age2_z sex ///
dis_gall_z comp  fed open ///
voc_spec_z ind_tra_z  ///
coord_z emprot_temp_z /// 
c.edulvla##c.ind_tra_z ///
c.edulvla##c.voc_spec_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.coord_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z [pweight = dweight] , vce(cluster cyear)



est store socrob2


estout  m21 socrob* ///
 using results20160214_socrob.csv , noomitted ///
cells("b(star fmt(3)) se[par]") ///
stats(N_g N ll aic bic, labels("N groups" "N individuals" Log-Likelihood ///
AIC BIC)) nolz replace


