




version 13
cd "C:\Users\rabuza\Documents\Promotion\Text\Kapitel 7 Politisch elektorale Effekte\Analyse\Stata"

log using anpol20160213, replace

use "C:\Users\rabuza\Documents\Promotion\Text\Kapitel  5 Institutionelle Effekte\Analyse\Data\Aktuellster Datensatz\merge_20150608.dta"


set more off




* Generate missing value on explanatory variable *

gen cogcomp_diff = cogcomp_hi - cogcomp_lo

misschk vote10 ager sex voc_spec edulvla open dis_gall comp ind_tra ///
fed coord emprot_temp lo_sec cogcomp_diff edusd polada_ext, gen(miss)

* Centering of continuous predictors at the macro-level

egen pickone = tag(cyear) if missnum == 0

sum ager if missnumber == 0
gen age_z = ager - r(mean)

sum age2 if missnumber == 0
gen age2_z = age2 - r(mean) 

sum edulvla if missnumber == 0
gen edulvla_z = edulvla - r(mean)


sum dis_gall if missnumber == 0  & pickone == 1
gen dis_gall_z = dis_gall - r(mean) if missnumber == 0

sum coord if missnumber == 0 & pickone == 1
gen coord_z = coord - r(mean) if missnumber == 0

sum ind_tra if  missnumber == 0 & pickone == 1
gen ind_tra_z = ind_tra - r(mean) if missnumber == 0

sum voc_spec if missnum == 0 & pickone == 1
gen vocspec_z = voc_spec - r(mean) if missnum == 0


sum emprot_temp if missnumber == 0  & pickone == 1
gen emprot_temp_z = emprot_temp - r(mean) if missnumber == 0


sum emprot_reg if missnumber == 0  & pickone == 1
gen  emprot_reg_z = emprot_reg - r(mean) if missnumber == 0


sum cogcomp_diff if missnumber == 0 & pickone == 1
gen cogcomp_diff_z = cogcomp_diff - r(mean) if missnumber == 0


sum lo_sec_25_64 if missnumber == 0  & pickone == 1
gen lo_sec_25_64_z = lo_sec_25_64 - r(mean) if missnumber == 0


sum edusd if missnum == 0 & pickone == 1
gen edusd_z = edusd - r(mean) if missnumber == 0


sum vote10 age_z sex edulvla if missnumber == 0

sum polada_ext  
gen pola_z = polada_ext - r(mean)





************************************************************
* Generate Politico Electoral Context Variables            *  
************************************************************

* This section generates the politico eletoral contextual variables:
* 1. Variables dealing with the (effective) number of left and rightist parties
* 2. Measures of Party Polarisation
* 3. Measures of government cohesion




* 1. Effective Number of Left Parliamentary Parties * 
*****************************************************

* generate share of left votes
gen leftshare = social1 + social2 /// 
+ social3 + social4 + social5 + social6 ///
+ social7 + social8 + leftsoc1 + leftsoc2 ///
+ leftsoc3 + comm1 + comm2 + comm3 + postco1

*generate share of left seats in parl
gen leftseats = ssocial1 + ssocial2 ///
+ ssocial3 + ssocial4 + ssocial5 + ssocial6 ///
+ ssocial7 + ssocial8 + sleftso1 + sleftso2 ///
+ sleftso3 + scomm1 + scomm2 + scomm3 + spostco1



* generate Herfindahl index of left parliamentary parties
gen effpar_left = 1/((ssocial1/leftseats)^2 + (ssocial2/leftseats)^2 ///
+ (ssocial3/leftseats)^2 + (ssocial4/leftseats)^2 ///
+ (ssocial5/leftseats)^2 + (ssocial6/leftseats)^2 ///
+ (ssocial7/leftseats)^2 + (ssocial8/leftseats)^2 ///
+ (sleftso1/leftseats)^2 + (sleftso2/leftseats)^2 ///
+ (sleftso3/leftseats)^2 + (scomm1/leftseats)^2 ///
+ (scomm2/leftseats)^2  + (scomm3/leftseats)^2 ///
+ (spostco1/leftseats)^2)

sum effpar_left
hist effpar_left



* share of extreme left parties (left of social democrats)

gen exleftseats = sleftso1 + sleftso2 ///
+ sleftso3 + scomm1 + scomm2 + scomm3 + spostco1



* Generate number of left parties

forvalues i = 1(1)8{
gen socd`i' = .
replace socd`i' = 1 if ssocial`i' != 0 & ssocial`i' != .
}

forvalues i = 1(1)3{
gen lsocd`i' = .
replace lsocd`i' = 1 if sleftso`i' != 0 & sleftso`i' != .
}

forvalues i = 1(1)3{
gen comd`i' = .
replace comd`i' = 1 if scomm`i' != 0 & scomm`i' != .
}

gen postcod = .
replace postcod = 1 if spostco1 !=0 & spostco1 != .

egen numleft = rowtotal(socd1 socd2 socd3 socd4 ///
 socd5 socd6 socd7 socd8 lsocd1 lsocd2 lsocd3 ///
 comd1 comd2 comd3 postcod)
 


* Generate Effective Number of Right Parliamentary Parties 


gen rightseats = sliberal1 + sliberal2 + sliberal3 + sliberal4 ///
+ sliberal5 + sliberal6 + sliberal7 + sliberal8 + sright1 ///
+ sright2 + sright3 + sright4 + sright5

sum rightseats


gen effpar_right = 1/((sliberal1/rightseats)^2 ///
+ (sliberal2/rightseats)^2 + (sliberal3/rightseats)^2  ///
+ (sliberal4/rightseats)^2 + (sliberal5/rightseats)^2   ///
+ (sliberal6/rightseats)^2 + (sliberal7/rightseats)^2   ///
+ (sliberal8/rightseats)^2 + (sright1/rightseats)^2  ///
+ (sright2/rightseats)^2 + (sright3/rightseats)^2  ///
+ (sright4/rightseats)^2 )

replace effpar_right = 0 if rightseats == 0



* Absolute number of right parl. parties

forvalues i = 1(1)8{
gen libd`i' = .
replace libd`i' = 1 if sliberal`i' != 0 & sliberal`i'!= .
}

forvalues i = 1(1)5{
gen rightd`i' = .
replace rightd`i' = 1 if sright`i' != 0 & sright`i' != . 
}



egen numright = rowtotal(libd1  libd2  libd3  libd4  libd5 libd6 ///
 libd7  libd8  rightd1  rightd2  rightd3  rightd4  rightd5)
 



* 3. Number of non-centrist parliamentary parties

* Effective Number of non-centrist parl. parties

gen effpar_sum = effpar_left + effpar_right



* Absolute number of non-centrist parl. parties

gen num_noncenter = numleft + numright



* Government cohesion (Index of ideological fractionalisation of cabinet)

* 1. step: Rescaling that all countries cabinet post share sum up to 100% 

gen cabweight = 100/(gov_right1 + gov_cent1 + gov_left1) 

gen cabright = gov_right1*cabweight
gen cableft = gov_left1*cabweight
gen cabcenter = gov_cent1*cabweight

gen sumcab = cabright +  cableft + cabcenter


* 2. step: Generating Index of  ideological fractionalisation of cabinet

gen cabfrac = 1/((cabright/100)^2 + (cableft/100)^2 + (cabcenter/100)^2) 



**************************************************************
**************************************************************
* Descriptive statistics and graphs of contextual variables  *
**************************************************************
**************************************************************

* Contents: I. Scatterplots, II. Dotplots of Education effect 
* III. Longitudinal Plots
* and Contextual Variables



sum numleft effpar_left numright effpar_right num_noncenter ///
effpar_sum cabfrac polada_ext if missnumber == 0  & pickone == 1

pwcorr fed open dis_gall_z ///
coord_z emprot_temp_z ///
cogcomp_diff_z lo_sec_25_64_z edusd_z ind_tra_z ///
numleft effpar_left numright effpar_right num_noncenter ///
effpar_sum cabfrac polada_ext if missnumber == 0  & pickone == 1



***************************************************************
* I. Scatterplots Education effect vs. Contextual Variables   *
***************************************************************

* 1. (Effective) Number of left/right/noncentrist Parties

* Leftist Parties (absolute and effective number)

tw (scatter edumfx numleft, legend(off) mcolor(gray) msize(small) /// 
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(small)) ///
ytitle("Durchschnittl. Marginaleffekt Bildung", size(small)) ///
xlabel(,labsize(small)) ///
xtitle("Anzahl linker Parteien", size(small))) ///
(lfit edumfx numleft, lcolor(black)) if pickone == 1 & missnum == 0

graph save numleft_scatter.gph, replace


tw (scatter edumfx effpar_left, legend(off) mcolor(gray) msize(small) ///
ytitle(, size(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(small)) /// 
xlabel(,labsize(small)) ///
xtitle("Effekt. Anzahl linker Parteien", size(small))) ///
(lfit edumfx effpar_left, lcolor(black)) if pickone == 1 

graph save effparleft_scatter.gph, replace



* Rightist Parties (absolute and effective number)

 tw (scatter edumfx numright,  legend(off) mcolor(gray) msize(small) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(small)) /// 
xlabel(,labsize(small)) /// 
xtitle("Anzahl rechter Parteien", size(small))) ///
(lfit edumfx numright, lcolor(black)) if pickone == 1 & missnum == 0

graph save numright_scatter.gph, replace


tw (scatter edumfx effpar_right, legend(off) mcolor(gray) msize(small) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(small)) /// 
xlabel(,labsize(small)) ///
xtitle("Effekt. Anzahl rechter Parteien", size(small))) ///
(lfit edumfx effpar_right, lcolor(black))  if pickone == 1 

graph save effparright_scatter.gph, replace

* Non-centric Parties (absolute and effective number)

tw (scatter edumfx num_noncenter,  legend(off) mcolor(gray) msize(small) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(small)) /// 
xlabel(,labsize(small)) ///
xtitle(, size(small)) ///
xtitle("Anzahl nicht-zentr. Parteien", size(small))) ///
(lfit edumfx num_noncenter, lcolor(black)) if pickone == 1

graph save numnoncenter_scatter.gph, replace


tw (scatter edumfx effpar_sum,  legend(off) mcolor(gray) msize(small) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(small)) /// 
xlabel(,labsize(small)) /// 
xtitle("Effekt. Anzahl nicht-zentr. Parteien", size(small))) ///
(lfit edumfx effpar_sum, lcolor(black)) if pickone == 1

graph save effnonc_scatter.gph , replace



* 2. Polarisation  of Party System *

* Data from Franzmann's (calculations based on Dalton (2008))

tw (scatter edumfx polada_ext if pickone == 1, legend(off) mcolor(gray) msize(small) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(small)) /// 
xlabel(,labsize(small)) ///
xtitle("Parteiensystem. Polarisierung", size(small))) ///
(lfit edumfx polada_ext, lcolor(black)) if pickone == 1

graph save pola_scatter.gph, replace

* 3. Cabinet Fractionalisation 

tw (scatter edumfx cabfrac if pickone == 1, legend(off) mcolor(gray) msize(small) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(small)) /// 
xlabel(,labsize(small)) ///
xtitle("Ideologische Fraktionalisierung Kabinett", size(small))) ///
(lfit edumfx cabfrac, lcolor(black)) if pickone == 1

graph save cabfrac_scatter.gph, replace

* Combined graph Number of Parties and Education

graph combine numleft_scatter.gph numright_scatter.gph numnoncenter_scatter.gph ///
 effparleft_scatter.gph  effparright_scatter.gph effnonc_scatter.gph ///
pola_scatter.gph cabfrac_scatter.gph, ///
graphregion(fcolor(white) color(white)) ysize(4) xsize(4)

graph save scatter_pol_comb.gph, replace





***************************************************************
* II. Dotplots Education effect vs. Contextual Variables      *
***************************************************************


* Effective Number of Left Parties

bys cntry: egen effparleft_mean  = mean(effpar_left)
sum effpar_left if missnumber == 0 & pickone == 1
local b = r(mean)

graph dot effparleft_mean  if missnumber == 0  & pickone == 1 ///
, over(country, sort(effparleft_mean ) des label(labsize(vsmall))) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(vsmall)) ///
ytitle("Effekt. Anzahl linker Parteien", size(vsmall)) ///
yline(`b')


graph save effparleft_dot.gph, replace


* Number of Left Parties

bys cntry: egen numleft_mean  = mean(numleft)
sum numleft if missnumber == 0 & pickone == 1
local b = r(mean)

graph dot numleft_mean  if missnumber == 0  & pickone == 1 ///
, over(country, sort(numleft_mean) des label(labsize(vsmall))) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(vsmall)) ///
ytitle("Anzahl linker Parteien", size(vsmall)) ///
yline(`b')


graph save numleft_dot.gph, replace


* Effective Number of Right Parties

bys cntry: egen effparright_mean  = mean(effpar_right)
sum effpar_right if missnumber == 0 & pickone == 1
local b = r(mean)

graph dot effparright_mean  if missnumber == 0  & pickone == 1 ///
, over(country, sort(effparright_mean ) des label(labsize(vsmall))) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(vsmall)) ///
ytitle("Effekt. Anzahl rechter Parteien", size(vsmall)) ///
yline(`b')


graph save effparright_dot.gph, replace


* Number of Right Parties

bys cntry: egen numright_mean  = mean(numright)
sum numright if missnumber == 0 & pickone == 1
local b = r(mean)

graph dot numright_mean  if missnumber == 0  & pickone == 1 ///
, over(country, sort(numright_mean) des label(labsize(vsmall))) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(vsmall)) ///
ytitle("Anzahl rechter Parteien", size(vsmall)) ///
yline(`b')


graph save numright_dot.gph  , replace


* Number of Non-centrist Parties

bys cntry: egen numnonc_mean  = mean(num_noncenter)
sum num_noncenter if missnumber == 0 & pickone == 1
local b = r(mean)

graph dot numnonc_mean  if missnumber == 0  & pickone == 1 ///
, over(country, sort(numnonc_mean) des label(labsize(vsmall))) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(vsmall)) ///
ytitle("Anzahl nicht-zentr. Parteien", size(vsmall)) ///
yline(`b')


graph save numnonc_dot.gph  , replace

* Effective Number of Non-centrist Parties

bys cntry: egen effparnonc_mean  = mean(effpar_sum)
sum effpar_sum if missnumber == 0 & pickone == 1
local b = r(mean)

graph dot effparnonc_mean  if missnumber == 0  & pickone == 1 ///
, over(country, sort(effparnonc_mean) des label(labsize(vsmall))) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(vsmall)) ///
ytitle("Effektive Anzahl nicht-zentr. Parteien", size(vsmall)) ///
yline(`b')


graph save effparnonc_dot.gph  , replace



* Polarisation 


bys cntry: egen pola_mean = mean(polada_ext)

sum polada_ext if missnumber == 0 & pickone == 1
local a = r(mean)

graph dot pola_mean if missnumber == 0  & pickone == 1 ///
, over(country, label(labsize(vsmall)) sort(pola_mean)  des) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(vsmall)) ///
ytitle("Ideologische Polarisierung des Parteiensystems", size(vsmall)) ///
yline(`a') 


graph save pola_dot.gph, replace



* Cabinet Fractionalisation  

bys cntry: egen cabfrac_mean  = mean(cabfrac)
sum cabfrac if missnumber == 0 & pickone == 1
local b = r(mean)

graph dot cabfrac_mean  if missnumber == 0  & pickone == 1 ///
, over(country, sort(cabfrac_mean) des label(labsize(vsmall))) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
ylabel(,valuelabel labsize(vsmall)) ///
ytitle("Ideologische Fraktionalisierung des Kabinetts", size(vsmall)) ///
yline(`b')

graph save cabfrac_dot.gph, replace


* Combined Dotplot

graph combine numleft_dot.gph numright_dot.gph numnonc_dot.gph ///
effparleft_dot.gph effparright_dot.gph effparnonc_dot.gph, ///
graphregion(fcolor(white) color(white)) 

graph save dot_parties.gph, replace

graph combine pola_dot.gph cabfrac_dot.gph,  ///
graphregion(fcolor(white) color(white)) 

graph save dot_pola_cabfrac.gph, replace

************************************************************************
* III. Graphical Analysis ISCED 1 vs. ISCED 5 over time                *
************************************************************************



*Generating Plots of turnout differences of education groups 
* over 5 waves of ESS 2002 - 2010


*1. step: Generating quartiles of continuous context variables

xtile per_effparleft = effpar_left, n(4) 
xtile per_effparright = effpar_right, n(4)

xtile per_polada_ext = polada_ext, n(4)

xtile per_cabfrac = cabfrac, n(4)

label define quartile 1"25% geringste" 2">25% bis Median" 3 "Median bis 75%" 4 ">75 bis 100%"  
label val  per_effparleft  per_effparright per_pola per_cabfrac quartile  

label define essround 1 "2002" 2 "2004" 3 "2006" 4 "2008" 5 "2010"
label value essround essround

*2. step: generating rarea graphs of turnout diffs by ESS wave

* Left Parties


bys essround per_effparleft: egen to_effparleft1= mean(to_isced1)
bys essround per_effparleft: egen to_effparleft5 = mean(to_isced5)

tw rarea to_effparleft1 to_effparleft5 essround, ///
by(per_effparleft, legend(off) note("") ///
	graphregion(fcolor(white) color(white)) ///
	plotregion(fcolor(white) color(white))) ///
xlabel(,valuelabel labsize(vsmall)) ///
ylabel(.6(.2)1 , labsize(small)) ///
ytitle("") xtitle("Effektive Anzahl linker Parteien", size(small)) 


graph save effparleft_long.gph, replace

gen numleft_rec = numleft
replace numleft_rec = . if numleft == 0

bys essround numleft_rec: egen to_numleft1= mean(to_isced1) if missnum == 0
bys essround numleft_rec: egen to_numleft5 = mean(to_isced5) if missnum == 0

tw rarea to_numleft1 to_numleft5 essround, ///
by(numleft_rec, row(1) legend(off) note("") ///
	graphregion(fcolor(white) color(white)) ///
	plotregion(fcolor(white) color(white))) ///
xlabel(,valuelabel labsize(vsmall)) ///
ylabel(.6(.2)1 , labsize(small)) ///
ytitle("") xtitle("Anzahl linker Parteien", size(small)) 


graph save numleft_long.gph, replace


* Right Parties

bys essround per_effparright: egen to_effparright1= mean(to_isced1)
bys essround per_effparright: egen to_effparright5 = mean(to_isced5)

tw rarea to_effparright1 to_effparright5 essround, ///
by(per_effparright, legend(off) note("") ///
	graphregion(fcolor(white) color(white)) ///
	plotregion(fcolor(white) color(white))) ///
xlabel(,valuelabel labsize(vsmall)) ///
ylabel(.6(.2)1 , labsize(small)) ///
ytitle("") xtitle("Effektive Anzahl rechter Parteien", size(small)) 


graph save effparright_long.gph, replace


bys essround numright: egen to_numright1 = mean(to_isced1) if missnum == 0
bys essround numright: egen to_numright5 = mean(to_isced5) if missnum == 0

gen numright_rec = numright
replace numright_rec = 4 if numright == 5


tw rarea to_numright1 to_numright5 essround, ///
by(numright_rec, row (1) legend(off) note("") ///
	graphregion(fcolor(white) color(white)) ///
	plotregion(fcolor(white) color(white))) ///
xlabel(,valuelabel labsize(vsmall)) ///
ylabel(.6(.2)1 , labsize(small)) ///
ytitle("") xtitle("Anzahl rechter Parteien", size(small)) 


graph save numright_long.gph, replace




* Polarisation of Party System

bys essround per_pola: egen to_pola1 = mean(to_isced1) if missnum == 0
bys essround per_pola: egen to_pola5 = mean(to_isced5) if missnum == 0

tw rarea to_pola1 to_pola5 essround, ///
by(per_pola, row(1) legend(off) note("") ///
	graphregion(fcolor(white) color(white)) ///
	plotregion(fcolor(white) color(white))) ///
xlabel(,valuelabel labsize(vsmall)) ///
ylabel(.6(.2)1 , labsize(small)) ///
ytitle("") xtitle("Polarisierung des Parteiensystems", size(small)) 


graph save pola_long.gph, replace


* Fractionalisation of Cabinet

bys essround per_cabfrac: egen to_cabfrac1 = mean(to_isced1) if missnum == 0
bys essround per_cabfrac: egen to_cabfrac5 = mean(to_isced5) if missnum == 0

tw rarea to_cabfrac1 to_cabfrac5 essround, ///
by(per_cabfrac, row(1) legend(off) note("") ///
	graphregion(fcolor(white) color(white)) ///
	plotregion(fcolor(white) color(white))) ///
xlabel(,valuelabel labsize(vsmall)) ///
ylabel(.6(.2)1 , labsize(small)) ///
ytitle("") xtitle("Fraktionalisierung des Kabinetts", size(small)) 

graph save cabfrac_long.gph, replace


graph combine numleft_long.gph numright_long.gph ///
pola_long.gph cabfrac_long.gph, row(6) ///
	graphregion(fcolor(white) color(white)) ///
	plotregion(fcolor(white) color(white))

	
graph save pol_long.gph, replace	
	
	