




version 13
cd "C:\Users\rabuza\Documents\Promotion\Text\Kapitel 7 Politisch elektorale Effekte\Analyse\Stata"

log using anpol20160216, replace

use "C:\Users\rabuza\Documents\Promotion\Text\Kapitel  5 Institutionelle Effekte\Analyse\Data\Aktuellster Datensatz\merge_20150608.dta"


set more off




* Generate missing value on explanatory variable *

gen cogcomp_diff = cogcomp_hi - cogcomp_lo

misschk vote10 ager sex voc_spec edulvla open dis_gall comp ind_tra ///
fed coord emprot_temp lo_sec cogcomp_diff edusd polada_ext, gen(miss)

* Centering of continuous predictors at the macro-level

egen pickone = tag(cyear) if missnum == 0

sum ager if missnumber == 0
gen age_z = ager - r(mean)

sum age2 if missnumber == 0
gen age2_z = age2 - r(mean) 

sum edulvla if missnumber == 0
gen edulvla_z = edulvla - r(mean)


sum dis_gall if missnumber == 0  & pickone == 1
gen dis_gall_z = dis_gall - r(mean) if missnumber == 0

sum coord if missnumber == 0 & pickone == 1
gen coord_z = coord - r(mean) if missnumber == 0

sum ind_tra if  missnumber == 0 & pickone == 1
gen ind_tra_z = ind_tra - r(mean) if missnumber == 0

sum voc_spec if missnum == 0 & pickone == 1
gen vocspec_z = voc_spec - r(mean) if missnum == 0


sum emprot_temp if missnumber == 0  & pickone == 1
gen emprot_temp_z = emprot_temp - r(mean) if missnumber == 0


sum emprot_reg if missnumber == 0  & pickone == 1
gen  emprot_reg_z = emprot_reg - r(mean) if missnumber == 0


sum cogcomp_diff if missnumber == 0 & pickone == 1
gen cogcomp_diff_z = cogcomp_diff - r(mean) if missnumber == 0


sum lo_sec_25_64 if missnumber == 0  & pickone == 1
gen lo_sec_25_64_z = lo_sec_25_64 - r(mean) if missnumber == 0


sum edusd if missnum == 0 & pickone == 1
gen edusd_z = edusd - r(mean) if missnumber == 0


sum vote10 age_z sex edulvla if missnumber == 0

sum polada_ext  
gen pola_z = polada_ext - r(mean)





************************************************************
* Generate Politico Electoral Context Variables            *  
************************************************************

* This section generates the politico eletoral contextual variables:
* 1. Variables dealing with the (effective) number of left and rightist parties
* 2. Measures of Party Polarisation
* 3. Measures of government cohesion




* 1. Effective Number of Left Parliamentary Parties * 
*****************************************************

* generate share of left votes
gen leftshare = social1 + social2 /// 
+ social3 + social4 + social5 + social6 ///
+ social7 + social8 + leftsoc1 + leftsoc2 ///
+ leftsoc3 + comm1 + comm2 + comm3 + postco1

*generate share of left seats in parl
gen leftseats = ssocial1 + ssocial2 ///
+ ssocial3 + ssocial4 + ssocial5 + ssocial6 ///
+ ssocial7 + ssocial8 + sleftso1 + sleftso2 ///
+ sleftso3 + scomm1 + scomm2 + scomm3 + spostco1



* generate Herfindahl index of left parliamentary parties
gen effpar_left = 1/((ssocial1/leftseats)^2 + (ssocial2/leftseats)^2 ///
+ (ssocial3/leftseats)^2 + (ssocial4/leftseats)^2 ///
+ (ssocial5/leftseats)^2 + (ssocial6/leftseats)^2 ///
+ (ssocial7/leftseats)^2 + (ssocial8/leftseats)^2 ///
+ (sleftso1/leftseats)^2 + (sleftso2/leftseats)^2 ///
+ (sleftso3/leftseats)^2 + (scomm1/leftseats)^2 ///
+ (scomm2/leftseats)^2  + (scomm3/leftseats)^2 ///
+ (spostco1/leftseats)^2)

sum effpar_left
hist effpar_left



* share of extreme left parties (left of social democrats)

gen exleftseats = sleftso1 + sleftso2 ///
+ sleftso3 + scomm1 + scomm2 + scomm3 + spostco1



* Generate number of left parties

forvalues i = 1(1)8{
gen socd`i' = .
replace socd`i' = 1 if ssocial`i' != 0 & ssocial`i' != .
}

forvalues i = 1(1)3{
gen lsocd`i' = .
replace lsocd`i' = 1 if sleftso`i' != 0 & sleftso`i' != .
}

forvalues i = 1(1)3{
gen comd`i' = .
replace comd`i' = 1 if scomm`i' != 0 & scomm`i' != .
}

gen postcod = .
replace postcod = 1 if spostco1 !=0 & spostco1 != .

egen numleft = rowtotal(socd1 socd2 socd3 socd4 ///
 socd5 socd6 socd7 socd8 lsocd1 lsocd2 lsocd3 ///
 comd1 comd2 comd3 postcod)
 


* Generate Effective Number of Right Parliamentary Parties 


gen rightseats = sliberal1 + sliberal2 + sliberal3 + sliberal4 ///
+ sliberal5 + sliberal6 + sliberal7 + sliberal8 + sright1 ///
+ sright2 + sright3 + sright4 + sright5

sum rightseats


gen effpar_right = 1/((sliberal1/rightseats)^2 ///
+ (sliberal2/rightseats)^2 + (sliberal3/rightseats)^2  ///
+ (sliberal4/rightseats)^2 + (sliberal5/rightseats)^2   ///
+ (sliberal6/rightseats)^2 + (sliberal7/rightseats)^2   ///
+ (sliberal8/rightseats)^2 + (sright1/rightseats)^2  ///
+ (sright2/rightseats)^2 + (sright3/rightseats)^2  ///
+ (sright4/rightseats)^2 )

replace effpar_right = 0 if rightseats == 0



* Absolute number of right parl. parties

forvalues i = 1(1)8{
gen libd`i' = .
replace libd`i' = 1 if sliberal`i' != 0 & sliberal`i'!= .
}

forvalues i = 1(1)5{
gen rightd`i' = .
replace rightd`i' = 1 if sright`i' != 0 & sright`i' != . 
}



egen numright = rowtotal(libd1  libd2  libd3  libd4  libd5 libd6 ///
 libd7  libd8  rightd1  rightd2  rightd3  rightd4  rightd5)
 



* 3. Number of non-centrist parliamentary parties

* Effective Number of non-centrist parl. parties

gen effpar_sum = effpar_left + effpar_right



* Absolute number of non-centrist parl. parties

gen num_noncenter = numleft + numright



* Government cohesion (Index of ideological fractionalisation of cabinet)

* 1. step: Rescaling that all countries cabinet post share sum up to 100% 

gen cabweight = 100/(gov_right1 + gov_cent1 + gov_left1) 

gen cabright = gov_right1*cabweight
gen cableft = gov_left1*cabweight
gen cabcenter = gov_cent1*cabweight

gen sumcab = cabright +  cableft + cabcenter


* 2. step: Generating Index of  ideological fractionalisation of cabinet

gen cabfrac = 1/((cabright/100)^2 + (cableft/100)^2 + (cabcenter/100)^2) 


		
	
	
*******************************************************************************	
*******************************************************************************
*******************************************************************************	
	
			***********************
			***********************
			* Regression Analysis *
			***********************
			***********************


********************************************************************************
********************************************************************************

* Null model


xtmelogit vote10 || cyear: if missnumber == 0, variance 

est store m0

estat icc




**********************
*                    *
* Random Intercept   *
*                    *
**********************

set more off
xtmelogit vote10 edulvla age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
|| cyear: , var mle

est store m1 

lrtest m1 m0 , force

estat icc


*****************
*               *
* Random Slope  *
*               *
*****************

set more off
xtmelogit vote10 edulvla age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z  ///
|| cyear: edulvla, var mle cov(unstructured)

est store m2
estat icc

lrtest m1 m2, force


****************************
*						   *
* Cross-level Interactions *
*                          *
****************************

* 1. Polarisation

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed pola_z ///
coord_z emprot_temp_z /// 
edulvla cogcomp_diff_z ///
pola_z || cyear: edulvla, var mle cov(unstructured)

est store pm4
estat icc

* model with interaction term
set more off

xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed pola_z ///
coord_z emprot_temp_z /// 
edulvla cogcomp_diff_z ///
c.edulvla##c.pola_z || cyear: edulvla, var mle cov(unstructured)

est store pm5
estat icc

lrtest  pm4 pm5, force


margins , at(pola_z=(-1(1)3) edulvl=(1 5)) predict(fixed)

marginsplot ,recast(line) recastci(rarea)
graph save pola_edu.gph, replace

set more off
sum pola_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(pola_z=( `a' `b' `c' )  edulvla=(1 5)) predict(fixed)




* 2. Number of non-centrist parliamentary parties

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla num_noncenter|| cyear: edulvla, var mle cov(unstructured)

est store pm6
estat icc


* model with interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla c.edulvla##c.num_noncenter|| cyear: edulvla, var mle cov(unstructured)

est store pm7
estat icc

estat icc
lrtest  pm6 pm7, force // test for signficant interaction term

set more off
margins , at(num_noncenter=(1(1)5) edulvl=(1 5)) predict(fixed)

marginsplot ,recast(line) recastci(rarea) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) ///
xlabel(, labsize(small)) ///
ytitle("") xtitle("Anzahl nicht-zentr. Parteien", size(small)) 

graph save numnoncenter_edu.gph, replace


* 3. Number of Left Parliamentary Parties

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla numleft|| cyear: edulvla, var mle cov(unstructured)


est store pm8
estat icc


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla c.edulvla##c.numleft|| cyear: edulvla, var mle cov(unstructured)

est store pm9
estat icc
lrtest  pm8 pm9, force

set more off
margins , at(numleft =(0(1)3) edulvla=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save numleft_edu.gph, replace

* 5. Number of Right Parliamentary Parties

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla numright|| cyear: edulvla, var mle cov(unstructured)


est store pm10
estat icc


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla c.edulvla##c.numright|| cyear: edulvla, var mle cov(unstructured)

est store pm11
estat icc
lrtest  pm10 pm11, force

set more off
margins , at(numright =(0(1)3) edulvla=(1(1)5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save numright_edu.gph, replace




* 4. Effective Number of Left Parliamentary Parties

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla effpar_left|| cyear: edulvla, var mle cov(unstructured)


est store pm12
estat icc


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla c.edulvla##c.effpar_left|| cyear: edulvla, var mle cov(unstructured)

est store pm13

estat icc

lrtest  pm12 pm13, force


set more off
margins , at(effpar_left =(0(1)2) edulvla=(1 5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save effparleft_edu.gph, replace

set more off
sum effpar_left if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(effpar_left=( `a' `b' `c' )  edulvla=(1 5)) predict(fixed)


* 5. Effective Number of Right Parliamentary Parties

* model without interaction term
set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla effpar_right|| cyear: edulvla, var mle cov(unstructured)


est store pm14
estat icc


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla c.edulvla##c.effpar_right|| cyear: edulvla, var mle cov(unstructured)

est store pm15
estat icc
lrtest  pm14 pm15, force

set more off
margins , at(effpar_right =(0(1)2) edulvla=(1 5)) predict(fixed)
marginsplot ,recast(line) recastci(rarea)

graph save effparright_edu.gph, replace



* Cabinet Fractionalisation

set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
edulvla c.cabfrac|| cyear: edulvla, var mle cov(unstructured)

est store pm16


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed ///
coord_z emprot_temp_z ///
c.edulvla##c.cabfrac|| cyear: edulvla, var mle cov(unstructured)

est store pm17
 
estat icc

lrtest pm16 pm17, force

set more off
sum cabfrac if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(cabfrac=( `a' `b' `c' )  edulvla=(1 5)) predict(fixed)




set more off
margins , at(cabfrac =(1(1)3) edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Frakjtionalisierung Kabinett", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save cabfrac_edu20160213.gph, replace

* Polarisation & Effective Number of Left Parties


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed pola_z ///
coord_z emprot_temp_z /// 
edulvla cogcomp_diff_z ///
c.edulvla##c.pola_z ///
c.edulvla##c.effpar_left|| cyear: edulvla, var mle cov(unstructured)

est store pm18
estat icc

lrtest  pm18 pm13, force
lrtest pm18 pm5, force 


* Institutional + Sociostructural +  Political Context

set more off
xtmelogit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.pola_z || cyear: edulvla, var mle cov(unstructured)

est store pm19
estat icc

lrtest pm18 pm19, force

estout m0 m1 m2 pm* ///
 using results20160214_pm1_pm19.csv , noomitted ///
cells("b(star fmt(3)) se[par]") ///
stats(N_g N ll aic bic, labels("N groups" "N individuals" Log-Likelihood ///
AIC BIC)) nolz replace


****************
* Diagnostics  *
****************


* Collinearity

reg vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.pola_z  , vce(cluster cyear)

estat vif



logit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.pola_z  , vce(cluster cyear)



***************************************************************************
* Plots / predicted probabilities for selected values of contetxual vars  *
* based on reatively best model	pm19										  *
***************************************************************************
set more off
sum  ind_tra_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(ind_tra_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)

* Stratification
set more off
margins , at(ind_tra_z = (-2(1)2)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Stratifizierung des Bildungssystems", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save pol_ind_tra_wcontrol.gph, replace


* Disporportionality

set more off
sum  dis_gall_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(dis_gall_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)

set more off
margins , at(dis_gall_z = (-6(5)21)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Elektorale Disproportionalitt", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save pol_disprop_wcontrol.gph, replace

* Cognitive Competence Gap

set more off
sum  cogcomp_diff_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(cogcomp_diff_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)

set more off
margins , at(cogcomp_diff_z = (-1(1)2)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Differenz kognitive Kompetenz", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save pol_cogcompdiff_wcontrol.gph, replace



*Share Low Educated

set more off
sum  lo_sec_25_64_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(lo_sec_25_64_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)

set more off
margins , at(lo_sec_25_64_z = (-20(10)60)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Anteil gering Gebildeter", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 

graph save pol_loedu_wcontrol.gph, replace

* Polarisation
set more off
sum  pola_z if missnum == 0 & pickone == 1
local a = r(min)
local b = r(mean)
local c = r(max)

margins , at(pola_z=(`a' `b' `c' ) edulvla=(1 5)) predict(fixed)

set more off
margins , at( pola_z= (-1(1)3)  edulvla=(1 5)) predict(fixed)
marginsplot ,recast(connected) ///
plot1opts(mcolor(black) msymbol(triangle) msize(small) lcolor(black) lwidth(thin)) ///
plot2opts(mcolor(black) msymbol(circle) msize(small) lcolor(black) lwidth(thin)) ///
recastci(rline) ciopts(color(black) lpattern(longdash) lwidth(thin)) ///
legend(off) ytitle("") xtitle("Polarisierung des Parteiensystems", size(small)) title("") ///
xlabel(,labsize(small)) ylabel(.5(.1)1, labsize(small)) ///
graphregion(fcolor(white) color(white)) ///
plotregion(fcolor(white) color(white)) 


graph save pol_pola_wcontrol.gph, replace, replace

graph combine 



***************************

set more off
xtmelogit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##i.open ///
c.edulvla##c.pola_z##c.pola_z || cyear: edulvla, var mle cov(unstructured)

est store pm20
estat icc

lrtest pm20 pm19, force // p = .144 

set more off
xtmelogit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##i.open ///
c.edulvla##c.pola_z ///
c.edulvla##c.cabfrac || cyear: edulvla, var mle cov(unstructured)

est store pm21
estat icc

lrtest pm21 pm19, force // p =  .233


set more off
xtmelogit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##i.open ///
c.edulvla##c.pola_z ///
c.edulvla##i.comp || cyear: edulvla, var mle cov(unstructured)

est store pm22



set more off
xtmelogit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##i.open ///
c.edulvla##c.pola_z ///
c.edulvla##i.comp || cyear: edulvla if comp == 0, var mle cov(unstructured)

est store pm23



**********************
* Robustness Checks  *
**********************

* With Population weight

xtset cyear_n

xtlogit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.pola_z [iweight = pweight] 

est store pmrob1

* With Design Weight

logit vote10 age_z age2_z sex  dis_gall_z comp fed ///
emprot_temp_z coord_z ///
c.edulvla##c.ind_tra_z ///
c.edulvla##c.cogcomp_diff_z ///
c.edulvla##c.lo_sec_25_64_z ///
c.edulvla##c.dis_gall_z ///
c.edulvla##c.pola_z [pweight = dweight] , vce(cluster cyear)

estat vif

est store pmrob2

estout m19 pmrob1 pmrob2 ///
 using results20160214_pmrob.csv , noomitted ///
cells("b(star fmt(3)) se[par]") ///
stats(N_g N ll aic bic, labels("N groups" "N individuals" Log-Likelihood ///
AIC BIC)) nolz replace


* Quadratic Polarisation term


set more off
xtmelogit vote10 age_z age2_z sex open dis_gall_z comp fed pola_z ///
coord_z emprot_temp_z /// 
edulvla cogcomp_diff_z ///
c.edulvla##c.pola_z##c.pola_z || cyear: edulvla, var mle cov(unstructured)

est store pm5_1

lrtest pm5 pm5_1, force 



